/*global define*/
/*jslint browser:true*/
define([
    'testsuite/qunit',
    'testsuite/qunit-fixture!./address-test',
    'testsuite/sinon',
    'jquery',
    'de_epages/usps/ui/address',
    'ep/ui/input'
], function ( QUnit, fixture, sinon, $) {

    'use strict';

    QUnit.module("de_epages/usps/ui/address", {
        setup: fixture.init,
        teardown: fixture.destroy
    });

    QUnit.asyncTest('Show Addresses to pick up the package (2 addresses found)', 3, function () {

        // We have to fake (use sinon.js) the POST request to get data
        var sandbox = sinon.sandbox.create(),
            server = sandbox.useFakeServer();

        server.autoRespond = true;
        server.autoRespondAfter = 400;
        server.respondWith('POST', '', [200, {
            'Content-Type': 'application/json'
        }, '{"HasError" : 0,"Addresses" : [{"FirmName" : "XYZ Corp.","Address1" : "Apartment 1","Address2" : "6406 IVY LN","City" : "GREENBELT","State" : "MD","Zip5" : "20770","Zip4" : "1441"},{"FirmName" : "XYZ Corp.","Address1" : "Apartment 2","Address2" : "6407 IVY LN","City" : "GREENBELT","State" : "MD","Zip5" : "20770","Zip4" : "1441"}]}']);

        $('#USPSAddressInformation')
            .uspsuiaddress({
                BasketID: '12345',
            });

        setTimeout(function () {

            QUnit.equal(
                $('.locations tr').length,
                4,
                'Check that the 2 addresses are shown with both titles. We expect 4 rows with 2 Addresses in the table'
            );

            QUnit.equal(
                $('.locations tr:eq(1) input[name=location]').val(),
                '0',
                'Check that the first radio button has the correct index of the addresses array. The value of the first radio element has to be 0'
            );

            QUnit.equal(
                $('.locations tr:eq(3) input[name=location]').val(),
                '1',
                'Check that the second radio button has the correct index of the addresses array. The value of the second radio element has to be 1'
            );

            QUnit.start();
        }, 5000);

    });

    QUnit.asyncTest('Show Addresses to pick up the package (no addresses found)', 1, function () {

        // We have to fake (use sinon.js) the POST request to get data
        var sandbox = sinon.sandbox.create(),
            server = sandbox.useFakeServer();

        server.autoRespond = true;
        server.autoRespondAfter = 400;
        server.respondWith('POST', '', [200, {
            'Content-Type': 'application/json'
        }, '[]']);

        $('#USPSAddressInformation')
            .uspsuiaddress({
            	BasketID: '1',
            });

        setTimeout(function () {

            QUnit.equal(
                $('.locations tr').length,
                0,
                'With no response we dont have to show anything. We expect to have no items in the table'
            );

            QUnit.start();
        }, 5000);

    });
    
    QUnit.asyncTest('Show Addresses to pick up the package (Bad response without data. Code 404)', 1, function () {

        // We have to fake (use sinon.js) the POST request to get data
        var sandbox = sinon.sandbox.create(),
            server = sandbox.useFakeServer();

        server.autoRespond = true;
        server.autoRespondAfter = 400;
        server.respondWith("POST", "", [404, {}, '']);

        $('#USPSAddressInformation')
            .uspsuiaddress({
            	BasketID: '1',
            });

        setTimeout(function () {

            QUnit.equal(
                $('.errormessages').length,
                1,
                'With an error code there has to be one element in the errormessage section. We expect 1 element in this div'
            );

            QUnit.start();
        }, 5000);

    });    
});