/*jslint browser: true, nomen: true*/
/*global define*/
define('de_epages/usps/ui/address', [
    'jquery',
    'ep',
    '$dict!ep/dict',
    '$tmpl!./address',
    '$tmpl!./address-row',
    'jquery/ui/widget',
    'jquery/metaparse',
    'ep/ajax',
    'ep/fn/busy'
], function ($, ep, epDict, tmpl, rowTmpl) {

    'use strict';

    $.widget('ui.uspsuiaddress', {
        options: {
            BasketId: null,
            tInfo: epDict.translate('{Info}'),
            tAddressChanged: epDict.translate('{DeliveryAddressChanged}'),
            tError: epDict.translate('{Error}'),
            tAddressIntroduced: epDict.translate('{AddressIntroduced}'),
            tAddressSuggested: epDict.translate('{AddressSuggested}'),
            tAddressValidated: epDict.translate('{AddressValidated}'),
            tAddressNotFound: epDict.translate('{AddressNotFound}')
        },

        _create: function () {
            var self = this,
                rendered = tmpl(self.options),
                tmplElements = rendered.tmplItem('elements');
            
            self.index = 0;
            
            rendered
                .appendTo(self.element)
                .find('.ep-js')
                .metaparse();

            $.extend(self, tmplElements);

            self._checkBasketAddress();

        },
        _saveSelectedAddress: function () {
            var self = this,
            	ActualAddress = '';
            ep('#USPSAddressInformation').busy('show');
            self.index = $('input[name=location]:checked').val();
            ActualAddress = self.AddressesData[self.index];

            ep.ajax({ // AJAX request
                data: {
                	ObjectID: self.options.BasketId,
                    ID: ActualAddress.ID,
                    FirmName: ActualAddress.FirmName,
                    Address1: ActualAddress.Address1,
                    Address2: ActualAddress.Address2,
                    Zip5: ActualAddress.Zip5,
                    Zip4: ActualAddress.Zip4,
                    City: ActualAddress.City,
                    State: ActualAddress.State,
                    ChangeAction: 'JSONUSPSSaveAddress',
                },
                cache: false,
                type: "POST",
                dataType: "json"
            }).done(function (data) {
            	ep('#USPSAddressInformation').busy('hide');
            	self.locations.empty();
            	self._showMessage(self.options.tAddressChanged);
            	self._updateLocationTable(0);
            }).fail(function (errJSON) {
                ep('#USPSAddressInformation').busy('hide');
                var thisJSON = $.parseJSON(errJSON.responseText);
                var errMessage;
                if(thisJSON == null){
                	self._showErrorMessage("CONECTION ERROR");
                } else {
                    errMessage = thisJSON.Errors[0].Reason;
                    self._showErrorMessage(errMessage);
                }
            });
        },
        _checkBasketAddress: function () {
            var self = this;
            ep('#USPSAddressInformation').busy('show');
            ep.ajax({ // AJAX request
                data: {
                    ObjectID: self.options.BasketId,
                    ChangeAction: 'JSONUSPSAddressInformation',
                },
                cache: false,
                type: "POST",
                dataType: "json"
            }).done(function (data) {
                ep('#USPSAddressInformation').busy('hide');
                if(data.HasError === 0){
                    if (data.Addresses.length > 1){
                        self.AddressesData = data.Addresses;
                        self._updateLocationTable(1);	
                    } else {
                        self._showMessage(self.options.tAddressValidated);
                    }
                } else if (data.HasError === 2){
                    self._showErrorMessage(self.options.tAddressNotFound);
                } else {
                	self._showErrorMessage(data.ErrorDesc);
                }
            }).fail(function (errJSON) {
                ep('#USPSAddressInformation').busy('hide'); 
                var thisJSON = $.parseJSON(errJSON.responseText);
                var errMessage;
                if(thisJSON == null){
                	self._showErrorMessage("CONECTION ERROR");
                } else {
                    errMessage = thisJSON.Errors[0].Reason;
                    self._showErrorMessage(errMessage);
                }
            });
        },

        _updateLocationTable: function (dosave) {
            this.locations.empty()
                .append(rowTmpl({addresses: this.AddressesData}))
                .find('.ep-js')
                .metaparse();
            this._selectLocation(this.index);
            if (dosave === 1) {
            	this._saveSelectedAddress();
            }
        },
        
        _showErrorMessage: function (errormessage) {
            this.errormessages.empty()
                .append(errormessage)
                .attr( 'class','DialogMessage MessageWarning' )
                .find('.ep-js')
                .metaparse();
        },

        _showMessage: function (message) {
            this.messages.empty()
                .append(message)
                .attr( 'class','DialogMessage MessageInfo' )
                .find('.ep-js')
                .metaparse();
        },

        _selectLocation: function (index) {
        	var self = this;
        	self.locations.find('.location_' + index)
                .prop('checked', 'checked');
            $('input[name=location]').change(function () {
            	if (this.checked) {
            		self._saveSelectedAddress();
            	}
            });
        },

        destroy: function () {
            this.element.empty();

            this._superApply(arguments);
        }
    });
    
    //return de_epages;
    
});